bug-coreutils
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

"filesystem" -> "file system" for coreutils


From: Paul Eggert
Subject: "filesystem" -> "file system" for coreutils
Date: Wed, 30 Jun 2004 14:09:38 -0700
User-agent: Gnus/5.1006 (Gnus v5.10.6) Emacs/21.3 (gnu/linux)

Coreutils sometimes uses "filesystem" and sometimes "file system".
It's better to be consistent in spelling.  I don't much care which,
but POSIX uses "file system" so the following proposed patch
standardizes on that.  The main change here is that stat's
--filesystem option gets renamed to --file-system.  The other changes
affect the documentation, and some usage and error messages.

Index: ChangeLog
===================================================================
RCS file: /home/meyering/coreutils/cu/ChangeLog,v
retrieving revision 1.970
diff -p -u -r1.970 ChangeLog
--- ChangeLog   28 Jun 2004 18:47:09 -0000      1.970
+++ ChangeLog   30 Jun 2004 20:57:44 -0000
@@ -1,3 +1,14 @@
+2004-06-30  Paul Eggert  <address@hidden>
+
+       * src/df.c (usage, main): Output "file system" rather than
+       "filesystem".
+       * src/du.c (usage): Likewise.
+       * src/shred.c (usage): Likewise.
+       * src/stat.c (usage): Likewise.
+       * src/stat.c (long_options, usage): Rename "--filesystem" to
+       "--file-system".  But keep the old name around, for compatibility
+       reasons.
+       
 2004-06-28  Jim Meyering  <address@hidden>
 
        * Version 5.3.0.
Index: NEWS
===================================================================
RCS file: /home/meyering/coreutils/cu/NEWS,v
retrieving revision 1.220
diff -p -u -r1.220 NEWS
--- NEWS        27 Jun 2004 09:41:46 -0000      1.220
+++ NEWS        30 Jun 2004 21:02:47 -0000
@@ -138,6 +138,9 @@ GNU coreutils NEWS                      
   The usual `--' operand is now supported by chroot, hostid, hostname,
   pwd, sync, and yes.
 
+  The stat option --filesystem has been renamed to --file-system, for
+  consistency with POSIX "file system" and with cp and du --one-file-system.
+
 * Major changes in release 5.2.1 (2004-03-12) [stable]
 
 ** Bug fixes
Index: doc/ChangeLog
===================================================================
RCS file: /home/meyering/coreutils/cu/doc/ChangeLog,v
retrieving revision 1.170
diff -p -u -r1.170 ChangeLog
--- doc/ChangeLog       17 Jun 2004 14:40:51 -0000      1.170
+++ doc/ChangeLog       30 Jun 2004 14:12:27 -0000
@@ -1,3 +1,8 @@
+2004-06-30  Paul Eggert  <address@hidden>
+
+       * coreutils.texi, perm.texi: Standardize on "file system" rather
+       than "filesystem", as POSIX prefers it with a space.
+
 2004-06-15  Paul Eggert  <address@hidden>
 
        * coreutils.texi (yes invocation): "--" is now supported.
Index: doc/coreutils.texi
===================================================================
RCS file: /home/meyering/coreutils/cu/doc/coreutils.texi,v
retrieving revision 1.189
diff -p -u -r1.189 coreutils.texi
--- doc/coreutils.texi  17 Jun 2004 14:38:52 -0000      1.189
+++ doc/coreutils.texi  30 Jun 2004 14:01:24 -0000
@@ -49,7 +49,7 @@
 * cut: (coreutils)cut invocation.               Print selected parts of lines.
 * date: (coreutils)date invocation.             Print/set system date and time.
 * dd: (coreutils)dd invocation.                 Copy and convert a file.
-* df: (coreutils)df invocation.                 Report filesystem disk usage.
+* df: (coreutils)df invocation.                 Report file system disk usage.
 * dir: (coreutils)dir invocation.               List directories briefly.
 * dircolors: (coreutils)dircolors invocation.   Color setup for ls.
 * dirname: (coreutils)dirname invocation.       Strip non-directory suffix.
@@ -317,9 +317,9 @@ Changing file attributes
 
 Disk usage
 
-* df invocation::               Report filesystem disk space usage
+* df invocation::               Report file system disk space usage
 * du invocation::               Estimate file space usage
-* stat invocation::             Report file or filesystem status
+* stat invocation::             Report file or file system status
 * sync invocation::             Synchronize data on disk with memory
 
 Printing text
@@ -746,7 +746,7 @@ It has been replaced with @address@hidden
 Some @sc{gnu} programs (at least @command{df}, @command{du}, and
 @command{ls}) display sizes in ``blocks''.  You can adjust the block size
 and method of display to make sizes easier to read.  The block size
-used for display is independent of any filesystem block size.
+used for display is independent of any file system block size.
 Fractional block counts are rounded up to the nearest integer.
 
 @opindex address@hidden
@@ -5419,7 +5419,7 @@ provide this option for compatibility.)
 @cindex inode number, printing
 Print the inode number (also called the file serial number and index
 number) of each file to the left of the file name.  (This number
-uniquely identifies each file within a particular filesystem.)
+uniquely identifies each file within a particular file system.)
 
 @item -l
 @itemx --format=long
@@ -6390,10 +6390,10 @@ refers to a non-regular file, then do no
 For each sufficiently long sequence of zero bytes in the input file,
 attempt to create a corresponding hole in the output file, even if the
 input file does not appear to be sparse.
-This is useful when the input file resides on a filesystem
+This is useful when the input file resides on a file system
 that does not support sparse files
-(for example,  @samp{efs} filesystems in SGI IRIX 5.3 and earlier),
-but the output file is on a type of filesystem that does support them.
+(for example,  @samp{efs} file systems in SGI IRIX 5.3 and earlier),
+but the output file is on a type of file system that does support them.
 Holes may be created only in regular files, so if the destination file
 is of some other type, @command{cp} does not even try to make it sparse.
 
@@ -6444,8 +6444,8 @@ Print the name of each file before copyi
 @itemx --one-file-system
 @opindex -x
 @opindex --one-file-system
address@hidden filesystems, omitting copying to different
-Skip subdirectories that are on different filesystems from the one that
address@hidden file systems, omitting copying to different
+Skip subdirectories that are on different file systems from the one that
 the copy started on.
 However, mount point directories @emph{are} copied.
 
@@ -6847,9 +6847,9 @@ Otherwise, if only two files are given, 
 the second.  It is an error if the last argument is not a directory
 and more than two files are given.
 
address@hidden can move any type of file from one filesystem to another.
address@hidden can move any type of file from one file system to another.
 Prior to version @code{4.0} of the fileutils,
address@hidden could move only regular files between filesystems.
address@hidden could move only regular files between file systems.
 For example, now @command{mv} can move an entire directory hierarchy
 including special device files from one partition to another.  It first
 uses some of the same code that's used by @code{cp -a} to copy the
@@ -6977,7 +6977,7 @@ don't require a directory to be empty be
 only if you have appropriate privileges and if your operating system supports
 @code{unlink} for directories.  Because unlinking a directory causes any files
 in the deleted directory to become unreferenced, it is wise to @command{fsck}
-the filesystem after doing this.
+the file system after doing this.
 
 @item -f
 @itemx --force
@@ -6997,7 +6997,7 @@ Ignore any previous @option{--force} (@o
 @itemx --preserve-root
 @opindex --preserve-root
 @cindex root directory, disallow recursive destruction
-Fail upon any attempt to remove the filesystem root, @file{/},
+Fail upon any attempt to remove the file system root, @file{/},
 when used with the @option{--recursive} option.
 Without @option{--recursive}, this option has no effect.
 @xref{Treating / specially}.
@@ -7094,37 +7094,37 @@ California, 22--25 July, 1996).  The pap
 @url{http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html}.
 
 @strong{Please note} that @command{shred} relies on a very important 
assumption:
-that the filesystem overwrites data in place.  This is the traditional
-way to do things, but many modern filesystem designs do not satisfy this
+that the file system overwrites data in place.  This is the traditional
+way to do things, but many modern file system designs do not satisfy this
 assumption.  Exceptions include:
 
 @itemize @bullet
 
 @item
-Log-structured or journaled filesystems, such as those supplied with
+Log-structured or journaled file systems, such as those supplied with
 AIX and Solaris, and JFS, ReiserFS, XFS, Ext3, etc.
 
 @item
-Filesystems that write redundant data and carry on even if some writes
-fail, such as RAID-based filesystems.
+File systems that write redundant data and carry on even if some writes
+fail, such as RAID-based file systems.
 
 @item
-Filesystems that make snapshots, such as Network Appliance's NFS server.
+File systems that make snapshots, such as Network Appliance's NFS server.
 
 @item
-Filesystems that cache in temporary locations, such as NFS version 3
+File systems that cache in temporary locations, such as NFS version 3
 clients.
 
 @item
-Compressed filesystems.
+Compressed file systems.
 @end itemize
 
-If you are not sure how your filesystem operates, then you should assume
+If you are not sure how your file system operates, then you should assume
 that it does not overwrite data in place, which means that shred cannot
-reliably operate on regular files in your filesystem.
+reliably operate on regular files in your file system.
 
 Generally speaking, it is more reliable to shred a device than a file,
-since this bypasses the problem of filesystem design mentioned above.
+since this bypasses the problem of file system design mentioned above.
 However, even shredding devices is not always completely reliable.  For
 example, most disks map out bad sectors invisibly to the application; if
 the bad sectors contain sensitive data, @command{shred} won't be able to
@@ -7197,7 +7197,7 @@ Display status updates as sterilization 
 @opindex -x
 @opindex --exact
 By default, @command{shred} rounds the size of a regular file up to the next
-multiple of the filesystem block size to fully erase the last block of the 
file.
+multiple of the file system block size to fully erase the last block of the 
file.
 Use @option{--exact} to suppress that behavior.
 Thus, by default if you shred a 10-byte regular file on a system with 512-byte
 blocks, the resulting file will be 512 bytes long.  With this option,
@@ -7242,7 +7242,7 @@ Bourne-compatible shell) the command @sa
 @end table
 
 You might use the following command to erase all trace of the
-filesystem you'd created on the floppy disk in your first drive.
+file system you'd created on the floppy disk in your first drive.
 That command takes about 20 minutes to erase a ``1.44MB'' (actually
 1440 KiB) floppy.
 
@@ -7330,7 +7330,7 @@ to create the link.
 @cindex symbolic (soft) links, creating
 @cindex creating links (hard or soft)
 
address@hidden filesystems and hard links
address@hidden file systems and hard links
 @command{ln} makes links between files.  By default, it makes hard links;
 with the @option{-s} option, it makes symbolic (or @dfn{soft}) links.
 Synopses:
@@ -7367,7 +7367,7 @@ original are indistinguishable.  Technic
 same inode, and the inode contains all the information about a
 file---indeed, it is not incorrect to say that the inode @emph{is} the
 file.  On all existing implementations, you cannot make a hard link to
-a directory, and hard links cannot cross filesystem boundaries.  (These
+a directory, and hard links cannot cross file system boundaries.  (These
 restrictions are not mandated by @acronym{POSIX}, however.)
 
 @cindex dereferencing symbolic links
@@ -7949,7 +7949,7 @@ during a recursive traversal, but see @o
 @itemx --preserve-root
 @opindex --preserve-root
 @cindex root directory, disallow recursive modification
-Fail upon any attempt to recursively change the filesystem root, @file{/}.
+Fail upon any attempt to recursively change the file system root, @file{/}.
 Without @option{--recursive}, this option has no effect.
 @xref{Treating / specially}.
 
@@ -8058,7 +8058,7 @@ during a recursive traversal, but see @o
 @itemx --preserve-root
 @opindex --preserve-root
 @cindex root directory, disallow recursive modification
-Fail upon any attempt to recursively change the filesystem root, @file{/}.
+Fail upon any attempt to recursively change the file system root, @file{/}.
 Without @option{--recursive}, this option has no effect.
 @xref{Treating / specially}.
 
@@ -8155,7 +8155,7 @@ changed.
 @itemx --preserve-root
 @opindex --preserve-root
 @cindex root directory, disallow recursive modification
-Fail upon any attempt to recursively change the filesystem root, @file{/}.
+Fail upon any attempt to recursively change the file system root, @file{/}.
 Without @option{--recursive}, this option has no effect.
 @xref{Treating / specially}.
 
@@ -8323,30 +8323,30 @@ it runs; for that, you want @command{ps}
 or some such command.)
 
 @menu
-* df invocation::               Report filesystem disk space usage.
+* df invocation::               Report file system disk space usage.
 * du invocation::               Estimate file space usage.
-* stat invocation::            Report file or filesystem status.
+* stat invocation::            Report file or file system status.
 * sync invocation::             Synchronize memory and disk.
 @end menu
 
 
 @node df invocation
address@hidden @command{df}: Report filesystem disk space usage
address@hidden @command{df}: Report file system disk space usage
 
 @pindex df
address@hidden filesystem disk usage
address@hidden disk usage by filesystem
address@hidden file system disk usage
address@hidden disk usage by file system
 
 @command{df} reports the amount of disk space used and available on
-filesystems.  Synopsis:
+file systems.  Synopsis:
 
 @example
 df address@hidden@dots{} address@hidden@dots{}
 @end example
 
 With no arguments, @command{df} reports the space used and available on all
-currently mounted filesystems (of all types).  Otherwise, @command{df}
-reports on the filesystem containing each argument @var{file}.
+currently mounted file systems (of all types).  Otherwise, @command{df}
+reports on the file system containing each argument @var{file}.
 
 Normally the disk space is printed in units of
 1024 bytes, but this can be overridden (@pxref{Block size}).
@@ -8355,11 +8355,11 @@ Non-integer quantities are rounded up to
 @cindex disk device file
 @cindex device file, disk
 If an argument @var{file} is a disk device file containing a mounted
-filesystem, @command{df} shows the space available on that filesystem
-rather than on the filesystem containing the device node (i.e., the root
-filesystem).  @sc{gnu} @command{df} does not attempt to determine the disk 
usage
-on unmounted filesystems, because on most kinds of systems doing so
-requires extremely nonportable intimate knowledge of filesystem
+file system, @command{df} shows the space available on that file system
+rather than on the file system containing the device node (i.e., the root
+file system).  @sc{gnu} @command{df} does not attempt to determine the disk 
usage
+on unmounted file systems, because on most kinds of systems doing so
+requires extremely nonportable intimate knowledge of file system
 structures.
 
 The program accepts the following options.  Also see @ref{Common options}.
@@ -8370,11 +8370,11 @@ The program accepts the following option
 @itemx --all
 @opindex -a
 @opindex --all
address@hidden automounter filesystems
address@hidden ignore filesystems
-Include in the listing filesystems that have a size of 0 blocks, which
-are omitted by default.  Such filesystems are typically special-purpose
-pseudo-filesystems, such as automounter entries.  Also, filesystems of
address@hidden automounter file systems
address@hidden ignore file systems
+Include in the listing file systems that have a size of 0 blocks, which
+are omitted by default.  Such file systems are typically special-purpose
+pseudo-file-systems, such as automounter entries.  Also, file systems of
 type ``ignore'' or ``auto'', supported by some operating systems, are
 only included if this option is specified.
 
@@ -8382,7 +8382,7 @@ only included if this option is specifie
 @itemx address@hidden
 @opindex -B
 @opindex --block-size
address@hidden filesystem sizes
address@hidden file system sizes
 Scale sizes by @var{size} before printing them (@pxref{Block size}).
 For example, @option{-BG} prints sizes in units of 1,073,741,824 bytes.
 
@@ -8403,7 +8403,7 @@ permissions, timestamps, and location on
 
 @item -k
 @opindex -k
address@hidden kibibytes for filesystem sizes
address@hidden kibibytes for file system sizes
 Print sizes in 1024-byte blocks, overriding the default block size
 (@pxref{Block size}).
 This option is equivalent to @option{--block-size=1K}.
@@ -8412,13 +8412,13 @@ This option is equivalent to @option{--b
 @itemx --local
 @opindex -l
 @opindex --local
address@hidden filesystem types, limiting output to certain
-Limit the listing to local filesystems.  By default, remote filesystems
address@hidden file system types, limiting output to certain
+Limit the listing to local file systems.  By default, remote file systems
 are also listed.
 
 @item --no-sync
 @opindex --no-sync
address@hidden filesystem space, retrieving old data more quickly
address@hidden file system space, retrieving old data more quickly
 Do not invoke the @code{sync} system call before getting any usage data.
 This may make @command{df} run significantly faster on systems with many
 disks, but on some systems (notably SunOS) the results may be slightly
@@ -8437,7 +8437,7 @@ for the following:
 
 @enumerate
 @item
-The information about each filesystem is always printed on exactly
+The information about each file system is always printed on exactly
 one line; a mount device is never put on a line by itself.  This means
 that if the mount device name is more than 20 characters long (e.g., for
 some network mounts), the columns are misaligned.
@@ -8450,27 +8450,27 @@ The labels in the header output line are
 
 @item --sync
 @opindex --sync
address@hidden filesystem space, retrieving current data more slowly
address@hidden file system space, retrieving current data more slowly
 Invoke the @code{sync} system call before getting any usage data.  On
 some systems (notably SunOS), doing this yields more up to date results,
 but in general this option makes @command{df} much slower, especially when
-there are many or very busy filesystems.
+there are many or very busy file systems.
 
 @item -t @var{fstype}
 @itemx address@hidden
 @opindex -t
 @opindex --type
address@hidden filesystem types, limiting output to certain
-Limit the listing to filesystems of type @var{fstype}.  Multiple
-filesystem types can be specified by giving multiple @option{-t} options.
address@hidden file system types, limiting output to certain
+Limit the listing to file systems of type @var{fstype}.  Multiple
+file system types can be specified by giving multiple @option{-t} options.
 By default, nothing is omitted.
 
 @item -T
 @itemx --print-type
 @opindex -T
 @opindex --print-type
address@hidden filesystem types, printing
-Print each filesystem's type.  The types printed here are the same ones
address@hidden file system types, printing
+Print each file system's type.  The types printed here are the same ones
 you can include or exclude with @option{-t} and @option{-x}.  The particular
 types printed are whatever is supported by the system.  Here are some of
 the common names (this list is certainly not exhaustive):
@@ -8478,35 +8478,35 @@ the common names (this list is certainly
 @table @samp
 
 @item nfs
address@hidden NFS filesystem type
-An NFS filesystem, i.e., one mounted over a network from another
address@hidden NFS file system type
+An NFS file system, i.e., one mounted over a network from another
 machine.  This is the one type name which seems to be used uniformly by
 all systems.
 
 @item address@hidden, address@hidden, address@hidden
address@hidden Linux filesystem types
address@hidden local filesystem types
address@hidden 4.2 @r{filesystem type}
address@hidden ufs @r{filesystem type}
address@hidden efs @r{filesystem type}
-A filesystem on a locally-mounted hard disk.  (The system might even
address@hidden Linux file system types
address@hidden local file system types
address@hidden 4.2 @r{file system type}
address@hidden ufs @r{file system type}
address@hidden efs @r{file system type}
+A file system on a locally-mounted hard disk.  (The system might even
 support more than one type here; Linux does.)
 
 @item address@hidden, }cdfs
address@hidden CD-ROM filesystem type
address@hidden High Sierra filesystem
address@hidden hsfs @r{filesystem type}
address@hidden cdfs @r{filesystem type}
-A filesystem on a CD-ROM drive.  HP-UX uses @samp{cdfs}, most other
address@hidden CD-ROM file system type
address@hidden High Sierra file system
address@hidden hsfs @r{file system type}
address@hidden cdfs @r{file system type}
+A file system on a CD-ROM drive.  HP-UX uses @samp{cdfs}, most other
 systems use @samp{hsfs} (@samp{hs} for ``High Sierra'').
 
 @item pcfs
address@hidden PC filesystem
address@hidden DOS filesystem
address@hidden MS-DOS filesystem
address@hidden diskette filesystem
address@hidden PC file system
address@hidden DOS file system
address@hidden MS-DOS file system
address@hidden diskette file system
 @opindex pcfs
-An MS-DOS filesystem, usually on a diskette.
+An MS-DOS file system, usually on a diskette.
 
 @end table
 
@@ -8514,9 +8514,9 @@ An MS-DOS filesystem, usually on a diske
 @itemx address@hidden
 @opindex -x
 @opindex --exclude-type
-Limit the listing to filesystems not of type @var{fstype}.
-Multiple filesystem types can be eliminated by giving multiple
address@hidden options.  By default, no filesystem types are omitted.
+Limit the listing to file systems not of type @var{fstype}.
+Multiple file system types can be eliminated by giving multiple
address@hidden options.  By default, no file system types are omitted.
 
 @item -v
 Ignored; for compatibility with System V versions of @command{df}.
@@ -8700,8 +8700,8 @@ of subdirectories.
 @itemx --one-file-system
 @opindex -x
 @opindex --one-file-system
address@hidden one filesystem, restricting @command{du} to
-Skip directories that are on different filesystems from the one that
address@hidden one file system, restricting @command{du} to
+Skip directories that are on different file systems from the one that
 the argument being processed is on.
 
 @item address@hidden
@@ -8733,11 +8733,11 @@ in HP-UX; it also affects the HP-UX @com
 
 
 @node stat invocation
address@hidden @command{stat}: Report file or filesystem status
address@hidden @command{stat}: Report file or file system status
 
 @pindex stat
 @cindex file status
address@hidden filesystem status
address@hidden file system status
 
 @command{stat} displays information about the specified file(s).  Synopsis:
 
@@ -8746,7 +8746,7 @@ stat address@hidden@dots{} address@hidden@
 @end example
 
 With no option, @command{stat} reports all information about the given files.
-But it also can be used to report the information of the filesystems the
+But it also can be used to report the information of the file systems the
 given files are located on. If the files are links, @command{stat} can
 also give information about the files the links point to.
 
@@ -8754,11 +8754,11 @@ also give information about the files th
 @table @samp
 
 @item -f
address@hidden --filesystem
address@hidden --file-system
 @opindex -f
address@hidden --filesystem
address@hidden filesystems
-Report information about the filesystems where the given files are located
address@hidden --file-system
address@hidden file systems
+Report information about the file systems where the given files are located
 instead of information about the files themselves.
 
 @item -L
@@ -8815,7 +8815,7 @@ Interpreted sequences for file stat are:
 @item %Z - Time of last change as seconds since Epoch
 @end itemize
 
-Interpreted sequences for filesystem stat are:
+Interpreted sequences for file system stat are:
 @itemize @bullet
 @item %n - File name
 @item %i - File System id in hex
@@ -8850,7 +8850,7 @@ call.
 @cindex crashes and corruption
 The kernel keeps data in memory to avoid doing (relatively slow) disk
 reads and writes.  This improves performance, but if the computer
-crashes, data may be lost or the filesystem corrupted as a
+crashes, data may be lost or the file system corrupted as a
 result. @command{sync} ensures everything in memory is written to disk.
 
 Any arguments are ignored, except for a lone @option{--help} or
@@ -9863,11 +9863,11 @@ these conditions is true:
 one of the existing directories in @var{name} does not have search
 (execute) permission,
 @item
-the length of @var{name} is larger than its filesystem's maximum
+the length of @var{name} is larger than its file system's maximum
 file name length,
 @item
 the length of one component of @var{name}, corresponding to an
-existing directory name, is larger than its filesystem's maximum
+existing directory name, is larger than its file system's maximum
 length for a file name component.
 @end enumerate
 
@@ -9879,7 +9879,7 @@ The program accepts the following option
 @itemx --portability
 @opindex -p
 @opindex --portability
-Instead of performing length checks on the underlying filesystem,
+Instead of performing length checks on the underlying file system,
 test the length of each file name and its components against the
 @acronym{POSIX} minimum limits for portability.  Also check that the file
 name contains no characters not in the portable file name character set.
Index: doc/perm.texi
===================================================================
RCS file: /home/meyering/coreutils/cu/doc/perm.texi,v
retrieving revision 1.10
diff -p -u -r1.10 perm.texi
--- doc/perm.texi       8 Feb 2003 20:31:48 -0000       1.10
+++ doc/perm.texi       30 Jun 2004 14:02:08 -0000
@@ -46,7 +46,7 @@ everyone else.
 Files are given an owner and group when they are created.  Usually the
 owner is the current user and the group is the group of the directory
 the file is in, but this varies with the operating system, the
-filesystem the file is created on, and the way the file is created.  You
+file system the file is created on, and the way the file is created.  You
 can change the owner and group of a file by using the @command{chown} and
 @command{chgrp} commands.
 
@@ -78,20 +78,20 @@ unless they own the file or the director
 @end enumerate
 
 In addition to the permissions listed above, there may be file attributes
-specific to the filesystem, e.g: access control lists (ACLs), whether a
+specific to the file system, e.g: access control lists (ACLs), whether a
 file is compressed, whether a file can be modified (immutability), whether
 a file can be dumped.  These are usually set using programs
-specific to the filesystem.  For example:
+specific to the file system.  For example:
 @c should probably say a lot more about ACLs... someday
 
 @table @asis
 @item ext2
 On GNU and Linux/GNU the file permissions (``attributes'') specific to
-the ext2 filesystem are set using @command{chattr}.
+the ext2 file system are set using @command{chattr}.
 
 @item FFS
 On FreeBSD the file permissions (``flags'') specific to the FFS
-filesystem are set using @command{chrflags}.
+file system are set using @command{chrflags}.
 @end table
 
 Although a file's permission ``bits'' allow an operation on that file,
@@ -99,10 +99,10 @@ that operation may still fail, because:
 
 @itemize
 @item
-the filesystem-specific permissions do not permit it;
+the file-system-specific permissions do not permit it;
 
 @item
-the filesystem is mounted as read-only.
+the file system is mounted as read-only.
 @end itemize
 
 For example, if the immutable attribute is set on a file,
Index: lib/ChangeLog
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/ChangeLog,v
retrieving revision 1.782
diff -p -u -r1.782 ChangeLog
--- lib/ChangeLog       24 Jun 2004 05:54:01 -0000      1.782
+++ lib/ChangeLog       30 Jun 2004 14:18:00 -0000
@@ -1,3 +1,10 @@
+2004-06-30  Paul Eggert  <address@hidden>
+
+       * dirname.h (FILE_SYSTEM_PREFIX_LEN): Renamed from
+       FILESYSTEM_PREFIX_LEN.  All uses changed.
+       * mountlist.h (read_file_system_list): Renamed from
+       read_filesystem_list.  All definitions and uses changed.
+
 2004-06-24  Jim Meyering  <address@hidden>
 
        * obstack.h (obstack_base): Fix parentheses.  From Paul Eggert.
Index: lib/backupfile.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/backupfile.c,v
retrieving revision 1.40
diff -p -u -r1.40 backupfile.c
--- lib/backupfile.c    10 Sep 2003 08:26:42 -0000      1.40
+++ lib/backupfile.c    30 Jun 2004 14:13:36 -0000
@@ -1,7 +1,7 @@
 /* backupfile.c -- make Emacs style backup file names
 
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998,
-   1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -124,7 +124,7 @@ find_backup_file_name (const char *file,
          size_t dirlen = dir_len (file);
 
          memcpy (s, file, dirlen);
-         if (dirlen == FILESYSTEM_PREFIX_LEN (file))
+         if (dirlen == FILE_SYSTEM_PREFIX_LEN (file))
            s[dirlen++] = '.';
          s[dirlen] = '\0';
          highest_backup = max_backup_version (base_name (file), s);
Index: lib/basename.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/basename.c,v
retrieving revision 1.22
diff -p -u -r1.22 basename.c
--- lib/basename.c      10 Sep 2003 08:28:38 -0000      1.22
+++ lib/basename.c      30 Jun 2004 14:14:01 -0000
@@ -1,7 +1,7 @@
 /* basename.c -- return the last element in a path
 
-   Copyright (C) 1990, 1998, 1999, 2000, 2001, 2003 Free Software
-   Foundation, Inc.
+   Copyright (C) 1990, 1998, 1999, 2000, 2001, 2003, 2004 Free
+   Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 char *
 base_name (char const *name)
 {
-  char const *base = name + FILESYSTEM_PREFIX_LEN (name);
+  char const *base = name + FILE_SYSTEM_PREFIX_LEN (name);
   char const *p;
 
   for (p = base; *p; p++)
Index: lib/dirname.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/dirname.c,v
retrieving revision 1.31
diff -p -u -r1.31 dirname.c
--- lib/dirname.c       10 Sep 2003 08:28:38 -0000      1.31
+++ lib/dirname.c       30 Jun 2004 14:14:12 -0000
@@ -1,5 +1,7 @@
 /* dirname.c -- return all but the last element in a path
-   Copyright (C) 1990, 1998, 2000, 2001, 2003 Free Software Foundation, Inc.
+
+   Copyright (C) 1990, 1998, 2000, 2001, 2003, 2004 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,7 +32,7 @@
 size_t
 dir_len (char const *path)
 {
-  size_t prefix_length = FILESYSTEM_PREFIX_LEN (path);
+  size_t prefix_length = FILE_SYSTEM_PREFIX_LEN (path);
   size_t length;
 
   /* Strip the basename and any redundant slashes before it.  */
@@ -51,7 +53,7 @@ char *
 dir_name (char const *path)
 {
   size_t length = dir_len (path);
-  int append_dot = (length == FILESYSTEM_PREFIX_LEN (path));
+  int append_dot = (length == FILE_SYSTEM_PREFIX_LEN (path));
   char *newpath = xmalloc (length + append_dot + 1);
   memcpy (newpath, path, length);
   if (append_dot)
Index: lib/dirname.h
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/dirname.h,v
retrieving revision 1.10
diff -p -u -r1.10 dirname.h
--- lib/dirname.h       29 May 2004 21:57:27 -0000      1.10
+++ lib/dirname.h       30 Jun 2004 13:54:37 -0000
@@ -29,8 +29,8 @@
 #  define ISSLASH(C) ((C) == DIRECTORY_SEPARATOR)
 # endif
 
-# ifndef FILESYSTEM_PREFIX_LEN
-#  define FILESYSTEM_PREFIX_LEN(Filename) 0
+# ifndef FILE_SYSTEM_PREFIX_LEN
+#  define FILE_SYSTEM_PREFIX_LEN(Filename) 0
 # endif
 
 # define IS_ABSOLUTE_FILE_NAME(Name) (ISSLASH (*Name))
Index: lib/euidaccess.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/euidaccess.c,v
retrieving revision 1.15
diff -p -u -r1.15 euidaccess.c
--- lib/euidaccess.c    10 Sep 2003 08:31:35 -0000      1.15
+++ lib/euidaccess.c    30 Jun 2004 14:14:38 -0000
@@ -1,7 +1,7 @@
 /* euidaccess -- check if effective user id can access file
 
-   Copyright (C) 1990, 1991, 1995, 1998, 2000, 2003 Free Software
-   Foundation, Inc.
+   Copyright (C) 1990, 1991, 1995, 1998, 2000, 2003, 2004 Free
+   Software Foundation, Inc.
 
    This file is part of the GNU C Library.
 
@@ -133,7 +133,7 @@ static int have_ids;
    otherwise, return -1 and set `errno' to EACCESS.
    Like access, except that it uses the effective user and group
    id's instead of the real ones, and it does not check for read-only
-   filesystem, text busy, etc. */
+   file system, text busy, etc. */
 
 int
 euidaccess (const char *path, int mode)
Index: lib/fsusage.h
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/fsusage.h,v
retrieving revision 1.10
diff -p -u -r1.10 fsusage.h
--- lib/fsusage.h       18 Aug 2003 09:44:49 -0000      1.10
+++ lib/fsusage.h       30 Jun 2004 14:14:54 -0000
@@ -1,6 +1,7 @@
-/* fsusage.h -- declarations for filesystem space usage info
+/* fsusage.h -- declarations for file system space usage info
 
-   Copyright (C) 1991, 1992, 1997, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1991, 1992, 1997, 2003, 2004 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* Space usage statistics for a filesystem.  Blocks are 512-byte. */
+/* Space usage statistics for a file system.  Blocks are 512-byte. */
 
 #if !defined FSUSAGE_H_
 # define FSUSAGE_H_
Index: lib/getloadavg.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/getloadavg.c,v
retrieving revision 1.23
diff -p -u -r1.23 getloadavg.c
--- lib/getloadavg.c    4 Apr 2004 06:51:11 -0000       1.23
+++ lib/getloadavg.c    30 Jun 2004 13:46:52 -0000
@@ -70,9 +70,9 @@
    UMAX4_3
    VMS
    WINDOWS32                   No-op for Windows95/NT.
-   __linux__                   Linux: assumes /proc filesystem mounted.
+   __linux__                   Linux: assumes /proc file system mounted.
                                Support from Michael K. Johnson.
-   __NetBSD__                  NetBSD: assumes /kern filesystem mounted.
+   __NetBSD__                  NetBSD: assumes /kern file system mounted.
 
    In addition, to avoid nesting many #ifdefs, we internally set
    LDAV_DONE to indicate that the load average has been computed.
Index: lib/path-concat.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/path-concat.c,v
retrieving revision 1.18
diff -p -u -r1.18 path-concat.c
--- lib/path-concat.c   4 Apr 2004 06:51:11 -0000       1.18
+++ lib/path-concat.c   30 Jun 2004 13:54:48 -0000
@@ -81,7 +81,7 @@ path_concat (const char *dir, const char
 
   p = mempcpy (p_concat, dir, dirlen);
 
-  if (FILESYSTEM_PREFIX_LEN (dir) < dirlen)
+  if (FILE_SYSTEM_PREFIX_LEN (dir) < dirlen)
     {
       if (ISSLASH (*(p - 1)) && ISSLASH (*base))
        --p;
Index: lib/savedir.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/savedir.c,v
retrieving revision 1.22
diff -p -u -r1.22 savedir.c
--- lib/savedir.c       10 Sep 2003 09:03:56 -0000      1.22
+++ lib/savedir.c       30 Jun 2004 14:14:30 -0000
@@ -1,7 +1,7 @@
 /* savedir.c -- save the list of files in a directory in a string
 
-   Copyright 1990, 1997, 1998, 1999, 2000, 2001, 2003 Free Software
-   Foundation, Inc.
+   Copyright 1990, 1997, 1998, 1999, 2000, 2001, 2003, 2004 Free
+   Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ savedir (const char *dir)
   while ((dp = readdir (dirp)) != NULL)
     {
       /* Skip "", ".", and "..".  "" is returned by at least one buggy
-         implementation: Solaris 2.4 readdir on NFS filesystems.  */
+         implementation: Solaris 2.4 readdir on NFS file systems.  */
       char const *entry = dp->d_name;
       if (entry[entry[0] != '.' ? 0 : entry[1] != '.' ? 1 : 2] != '\0')
        {
Index: m4/ChangeLog
===================================================================
RCS file: /home/meyering/coreutils/cu/m4/ChangeLog,v
retrieving revision 1.587
diff -p -u -r1.587 ChangeLog
--- m4/ChangeLog        25 Jun 2004 21:11:01 -0000      1.587
+++ m4/ChangeLog        30 Jun 2004 14:22:05 -0000
@@ -1,3 +1,14 @@
+2004-06-30  Paul Eggert  <address@hidden>
+
+       * dos.m4 (gl_AC_DOS): Define FILE_SYSTEM_PREFIX_LEN, not
+       FILESYSTEM_PREFIX_LEN.  Generate
+       FILE_SYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX, not
+       FILESYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX.  Generate
+       FILE_SYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR, not
+       FILESYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR.
+       * ls-mntd-fs.m4 (gl_LIST_MOUNTED_FILE_SYSTEMS): Renamed from
+       gl_LIST_MOUNTED_FILESYSTEMS.  All uses changed.
+       
 2004-06-25  Jim Meyering  <address@hidden>
 
        * afs.m4 (gl_AFS): Use AC_ARG_WITH instead of ancient, hard-coded
Index: m4/dos.m4
===================================================================
RCS file: /home/meyering/coreutils/cu/m4/dos.m4,v
retrieving revision 1.9
diff -p -u -r1.9 dos.m4
--- m4/dos.m4   13 Apr 2004 15:28:45 -0000      1.9
+++ m4/dos.m4   30 Jun 2004 14:02:56 -0000
@@ -25,28 +25,28 @@ neither MSDOS nor Windows
       ac_fs_backslash_is_file_name_separator=0
     fi
 
-    AH_VERBATIM(FILESYSTEM_PREFIX_LEN,
-    [#if FILESYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX
-# define FILESYSTEM_PREFIX_LEN(Filename) \
+    AH_VERBATIM(FILE_SYSTEM_PREFIX_LEN,
+    [#if FILE_SYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX
+# define FILE_SYSTEM_PREFIX_LEN(Filename) \
   ((Filename)[0] && (Filename)[1] == ':' ? 2 : 0)
 #else
-# define FILESYSTEM_PREFIX_LEN(Filename) 0
+# define FILE_SYSTEM_PREFIX_LEN(Filename) 0
 #endif])
 
-    AC_DEFINE_UNQUOTED([FILESYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX],
+    AC_DEFINE_UNQUOTED([FILE_SYSTEM_ACCEPTS_DRIVE_LETTER_PREFIX],
       $ac_fs_accepts_drive_letter_prefix,
       [Define on systems for which file names may have a so-called
        `drive letter' prefix, define this to compute the length of that
        prefix, including the colon.])
 
     AH_VERBATIM(ISSLASH,
-    [#if FILESYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR
+    [#if FILE_SYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR
 # define ISSLASH(C) ((C) == '/' || (C) == '\\')
 #else
 # define ISSLASH(C) ((C) == '/')
 #endif])
 
-    AC_DEFINE_UNQUOTED([FILESYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR],
+    AC_DEFINE_UNQUOTED([FILE_SYSTEM_BACKSLASH_IS_FILE_NAME_SEPARATOR],
       $ac_fs_backslash_is_file_name_separator,
       [Define if the backslash character may also serve as a file name
        component separator.])
Index: m4/fsusage.m4
===================================================================
RCS file: /home/meyering/coreutils/cu/m4/fsusage.m4,v
retrieving revision 1.17
diff -p -u -r1.17 fsusage.m4
--- m4/fsusage.m4       13 Apr 2004 15:28:45 -0000      1.17
+++ m4/fsusage.m4       30 Jun 2004 14:03:11 -0000
@@ -13,7 +13,7 @@ AC_DEFUN([gl_FSUSAGE],
   fi
 ])
 
-# Try to determine how a program can obtain filesystem usage information.
+# Try to determine how a program can obtain file system usage information.
 # If successful, define the appropriate symbol (see fsusage.c) and
 # execute ACTION-IF-FOUND.  Otherwise, execute ACTION-IF-NOT-FOUND.
 #
@@ -22,7 +22,7 @@ AC_DEFUN([gl_FSUSAGE],
 AC_DEFUN([gl_FILE_SYSTEM_USAGE],
 [
 
-echo "checking how to get filesystem space usage..."
+echo "checking how to get file system space usage..."
 ac_fsusage_space=no
 
 # Perform only the link test since it seems there are no variants of the
@@ -199,7 +199,7 @@ if test $ac_fsusage_space = no; then
   AC_TRY_CPP([#include <sys/filsys.h>
     ],
     AC_DEFINE(STAT_READ_FILSYS, 1,
-      [Define if there is no specific function for reading filesystems usage
+      [Define if there is no specific function for reading file systems usage
        information and you have the <sys/filsys.h> header file.  (SVR2)])
     ac_fsusage_space=yes)
 fi
Index: m4/ls-mntd-fs.m4
===================================================================
RCS file: /home/meyering/coreutils/cu/m4/ls-mntd-fs.m4,v
retrieving revision 1.27
diff -p -u -r1.27 ls-mntd-fs.m4
--- m4/ls-mntd-fs.m4    13 Apr 2004 15:28:45 -0000      1.27
+++ m4/ls-mntd-fs.m4    30 Jun 2004 14:23:01 -0000
@@ -6,8 +6,8 @@ dnl This is not pretty.  I've just taken
 dnl it in an AC_DEFUN.
 dnl
 
-# gl_LIST_MOUNTED_FILESYSTEMS([ACTION-IF-FOUND[, ACTION-IF-NOT-FOUND]])
-AC_DEFUN([gl_LIST_MOUNTED_FILESYSTEMS],
+# gl_LIST_MOUNTED_FILE_SYSTEMS([ACTION-IF-FOUND[, ACTION-IF-NOT-FOUND]])
+AC_DEFUN([gl_LIST_MOUNTED_FILE_SYSTEMS],
   [
 AC_CHECK_FUNCS(listmntent getmntinfo)
 AC_CHECK_HEADERS_ONCE(sys/param.h)
@@ -35,7 +35,7 @@ $ac_includes_default
 "
 AC_CHECK_MEMBERS([struct fsstat.f_fstypename],,,[$getfsstat_includes])
 
-# Determine how to get the list of mounted filesystems.
+# Determine how to get the list of mounted file systems.
 ac_list_mounted_fs=
 
 # If the getmntent function is available but not in the standard library,
@@ -70,7 +70,7 @@ yes
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_LISTMNTENT, 1,
       [Define if there is a function named listmntent that can be used to
-       list all mounted filesystems. (UNICOS)])
+       list all mounted file systems.  (UNICOS)])
   fi
 fi
 
@@ -86,7 +86,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_VMOUNT, 1,
        [Define if there is a function named mntctl that can be used to read
-         the list of mounted filesystems, and there is a system header file
+         the list of mounted file systems, and there is a system header file
          that declares `struct vmount.'  (AIX)])
   fi
 fi
@@ -125,7 +125,7 @@ if test $ac_cv_func_getmntent = yes; the
       ac_list_mounted_fs=found
       AC_DEFINE(MOUNTED_GETMNTENT1, 1,
         [Define if there is a function named getmntent for reading the list
-         of mounted filesystems, and that function takes a single argument.
+         of mounted file systems, and that function takes a single argument.
          (4.3BSD, SunOS, HP-UX, Dynix, Irix)])
     fi
   fi
@@ -142,7 +142,7 @@ if test $ac_cv_func_getmntent = yes; the
       ac_list_mounted_fs=found
       AC_DEFINE(MOUNTED_GETMNTENT2, 1,
         [Define if there is a function named getmntent for reading the list of
-         mounted filesystems, and that function takes two arguments.  (SVR4)])
+         mounted file systems, and that function takes two arguments.  (SVR4)])
     fi
   fi
 
@@ -173,7 +173,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_GETFSSTAT, 1,
              [Define if there is a function named getfsstat for reading the
-               list of mounted filesystems.  (DEC Alpha running OSF/1)])
+               list of mounted file systems.  (DEC Alpha running OSF/1)])
   fi
 fi
 
@@ -192,7 +192,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_FREAD_FSTYP, 1,
       [Define if (like SVR2) there is no specific function for reading the
-       list of mounted filesystems, and your system has these header files:
+       list of mounted file systems, and your system has these header files:
        <sys/fstyp.h> and <sys/statfs.h>.  (SVR3)])
   fi
 fi
@@ -211,7 +211,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_GETMNTINFO, 1,
              [Define if there is a function named getmntinfo for reading the
-               list of mounted filesystems.  (4.4BSD, Darwin)])
+               list of mounted file systems.  (4.4BSD, Darwin)])
   fi
 fi
 
@@ -229,7 +229,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_GETMNT, 1,
       [Define if there is a function named getmnt for reading the list of
-       mounted filesystems.  (Ultrix)])
+       mounted file systems.  (Ultrix)])
   fi
 fi
 
@@ -250,7 +250,7 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_FS_STAT_DEV, 1,
       [Define if there are functions named next_dev and fs_stat_dev for
-       reading the list of mounted filesystems.  (BeOS)])
+       reading the list of mounted file systems.  (BeOS)])
   fi
 fi
 
@@ -266,13 +266,13 @@ if test -z "$ac_list_mounted_fs"; then
     ac_list_mounted_fs=found
     AC_DEFINE(MOUNTED_FREAD, 1,
              [Define if there is no specific function for reading the list of
-               mounted filesystems.  fread will be used to read /etc/mnttab.
+               mounted file systems.  fread will be used to read /etc/mnttab.
                (SVR2) ])
   fi
 fi
 
 if test -z "$ac_list_mounted_fs"; then
-  AC_MSG_ERROR([could not determine how to read list of mounted filesystems])
+  AC_MSG_ERROR([could not determine how to read list of mounted file systems])
   # FIXME -- no need to abort building the whole package
   # Can't build mountlist.c or anything that needs its functions
 fi
Index: m4/mountlist.m4
===================================================================
RCS file: /home/meyering/coreutils/cu/m4/mountlist.m4,v
retrieving revision 1.3
diff -p -u -r1.3 mountlist.m4
--- m4/mountlist.m4     13 Apr 2004 15:28:45 -0000      1.3
+++ m4/mountlist.m4     30 Jun 2004 14:04:15 -0000
@@ -8,18 +8,18 @@ dnl the same distribution terms as the r
 
 AC_DEFUN([gl_MOUNTLIST],
 [
-  gl_LIST_MOUNTED_FILESYSTEMS([gl_cv_list_mounted_fs=yes],
-                              [gl_cv_list_mounted_fs=no])
+  gl_LIST_MOUNTED_FILE_SYSTEMS([gl_cv_list_mounted_fs=yes],
+                                      [gl_cv_list_mounted_fs=no])
   if test $gl_cv_list_mounted_fs = yes; then
     AC_LIBOBJ(mountlist)
     gl_PREREQ_MOUNTLIST_EXTRA
   fi
 ])
 
-# Prerequisites of lib/mountlist.c not done by gl_LIST_MOUNTED_FILESYSTEMS.
+# Prerequisites of lib/mountlist.c not done by gl_LIST_MOUNTED_FILE_SYSTEMS.
 AC_DEFUN([gl_PREREQ_MOUNTLIST_EXTRA],
 [
-  dnl Note gl_LIST_MOUNTED_FILESYSTEMS checks for mntent.h, not sys/mntent.h.
+  dnl Note gl_LIST_MOUNTED_FILE_SYSTEMS checks for mntent.h, not sys/mntent.h.
   AC_CHECK_HEADERS_ONCE(fcntl.h unistd.h)
   AC_CHECK_HEADERS(sys/mntent.h)
   gl_FSTYPENAME
Index: src/cat.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/cat.c,v
retrieving revision 1.94
diff -p -u -r1.94 cat.c
--- src/cat.c   15 Apr 2004 10:52:04 -0000      1.94
+++ src/cat.c   30 Jun 2004 13:54:37 -0000
@@ -244,7 +244,7 @@ cat (
 
 #ifdef FIONREAD
   /* If nonzero, use the FIONREAD ioctl, as an optimization.
-     (On Ultrix, it is not supported on NFS filesystems.)  */
+     (On Ultrix, it is not supported on NFS file systems.)  */
   int use_fionread = 1;
 #endif
 
Index: src/copy.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/copy.c,v
retrieving revision 1.165
diff -p -u -r1.165 copy.c
--- src/copy.c  20 Jun 2004 13:47:24 -0000      1.165
+++ src/copy.c  30 Jun 2004 13:54:37 -0000
@@ -1158,7 +1158,7 @@ copy_internal (const char *src_path, con
 
   if (earlier_file)
     {
-      /* Avoid damaging the destination filesystem by refusing to preserve
+      /* Avoid damaging the destination file system by refusing to preserve
         hard-linked directories (which are found at least in Netapp snapshot
         directories).  */
       if (S_ISDIR (src_type))
Index: src/copy.h
===================================================================
RCS file: /home/meyering/coreutils/cu/src/copy.h,v
retrieving revision 1.28
diff -p -u -r1.28 copy.h
--- src/copy.h  7 Feb 2004 16:01:02 -0000       1.28
+++ src/copy.h  30 Jun 2004 14:22:40 -0000
@@ -97,7 +97,7 @@ struct cp_options
   uid_t myeuid;
 
   /* If nonzero, when copying recursively, skip any subdirectories that are
-     on different filesystems from the one we started on. */
+     on different file systems from the one we started on.  */
   int one_file_system;
 
   /* If nonzero, attempt to give the copies the original files' permissions,
Index: src/du.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/du.c,v
retrieving revision 1.196
diff -p -u -r1.196 du.c
--- src/du.c    21 Jun 2004 15:03:35 -0000      1.196
+++ src/du.c    30 Jun 2004 13:54:37 -0000
@@ -207,7 +207,7 @@ Mandatory arguments to long options are 
   -s, --summarize       display only a total for each argument\n\
 "), stdout);
       fputs (_("\
-  -x, --one-file-system  skip directories on different filesystems\n\
+  -x, --one-file-system  skip directories on different file systems\n\
   -X FILE, --exclude-from=FILE  Exclude files that match any pattern in 
FILE.\n\
       --exclude=PATTERN Exclude files that match PATTERN.\n\
       --max-depth=N     print the total for a directory (or file, with 
--all)\n\
Index: src/mv.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/mv.c,v
retrieving revision 1.155
diff -p -u -r1.155 mv.c
--- src/mv.c    28 Jun 2004 18:39:28 -0000      1.155
+++ src/mv.c    30 Jun 2004 13:54:37 -0000
@@ -168,7 +168,7 @@ target_directory_operand (char const *fi
   return is_a_dir;
 }
 
-/* Move SOURCE onto DEST.  Handles cross-filesystem moves.
+/* Move SOURCE onto DEST.  Handles cross-file-system moves.
    If SOURCE is a directory, DEST must not exist.
    Return 0 if successful, 1 if an error occurred.  */
 
Index: src/pathchk.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/pathchk.c,v
retrieving revision 1.77
diff -p -u -r1.77 pathchk.c
--- src/pathchk.c       21 Jun 2004 15:03:35 -0000      1.77
+++ src/pathchk.c       30 Jun 2004 13:54:37 -0000
@@ -28,7 +28,7 @@
 
    Options:
    -p, --portability   Instead of performing length checks on the
-                       underlying filesystem, test the length of the
+                       underlying file system, test the length of the
                        pathname and its components against the POSIX
                        minimum limits for portability, _POSIX_NAME_MAX
                        and _POSIX_PATH_MAX in 2.9.2.  Also check that
Index: src/system.h
===================================================================
RCS file: /home/meyering/coreutils/cu/src/system.h,v
retrieving revision 1.89
diff -p -u -r1.89 system.h
--- src/system.h        19 Jun 2004 09:23:52 -0000      1.89
+++ src/system.h        30 Jun 2004 13:53:46 -0000
@@ -319,7 +319,7 @@ initialize_exit_failure (int status)
                              ? (statbuf).st_blksize : DEV_BSIZE)
 # if defined hpux || defined __hpux__ || defined __hpux
 /* HP-UX counts st_blocks in 1024-byte units.
-   This loses when mixing HP-UX and BSD filesystems with NFS.  */
+   This loses when mixing HP-UX and BSD file systems with NFS.  */
 #  define ST_NBLOCKSIZE 1024
 # else /* !hpux */
 #  if defined _AIX && defined _I386
Index: tests/du/deref-args
===================================================================
RCS file: /home/meyering/coreutils/cu/tests/du/deref-args,v
retrieving revision 1.5
diff -p -u -r1.5 deref-args
--- tests/du/deref-args 10 Mar 2004 18:06:04 -0000      1.5
+++ tests/du/deref-args 30 Jun 2004 14:04:48 -0000
@@ -36,7 +36,7 @@ du -D slink/ | sed 's/^[0-9][0-9]*    //' >
 # Ensure that -D makes du dereference even symlinks to non-directories.
 # The sed command maps the 68 I get on an ext3 file system to the 64 I 
expected.
 # On tmpfs, I get 64.  Similarly, on SELinux-enabled systems, file security
-# context labels take up filesystem space, making du print 72 here.
+# context labels take up file system space, making du print 72 here.
 du -kD slink-to-64k | sed 's/^[67][0-9]/64/' >> out
 cat <<\EOF > exp
 slink/a




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: lib/fsusage.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/fsusage.c,v
retrieving revision 1.46
diff -p -u -r1.46 fsusage.c
--- lib/fsusage.c       6 Jun 2003 19:46:45 -0000       1.46
+++ lib/fsusage.c       30 Jun 2004 14:14:46 -0000
@@ -1,6 +1,6 @@
 /* fsusage.c -- return space usage of mounted filesystems
 
-   Copyright (C) 1991, 1992, 1996, 1998, 1999, 2002, 2003 Free
+   Copyright (C) 1991, 1992, 1996, 1998, 1999, 2002, 2003, 2004 Free
    Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -102,7 +102,7 @@ int statvfs ();
 #define PROPAGATE_TOP_BIT(x) ((x) | ~ (EXTRACT_TOP_BIT (x) - 1))
 
 /* Fill in the fields of FSP with information about space usage for
-   the filesystem on which PATH resides.
+   the file system on which PATH resides.
    DISK is the device on which PATH is mounted, for space-getting
    methods that need to know it.
    Return 0 if successful, -1 if not.  When returning -1, ensure that
@@ -1,6 +1,6 @@
-/* fsusage.c -- return space usage of mounted filesystems
+/* fsusage.c -- return space usage of mounted file systems
 
Index: lib/mountlist.c
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/mountlist.c,v
retrieving revision 1.45
diff -p -u -r1.45 mountlist.c
--- lib/mountlist.c     29 Jan 2004 20:41:16 -0000      1.45
+++ lib/mountlist.c     30 Jun 2004 13:46:52 -0000
@@ -1,4 +1,4 @@
 /* mountlist.c -- return a list of mounted filesystems
    Copyright (C) 1991, 1992, 1997-2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -296,13 +296,13 @@ fstype_to_string (int t)
 }
 #endif /* MOUNTED_VMOUNT */
 
 /* Return a list of the currently mounted filesystems, or NULL on error.
    Add each entry to the tail of the list so that they stay in order.
-   If NEED_FS_TYPE is nonzero, ensure that the filesystem type fields in
+   If NEED_FS_TYPE is nonzero, ensure that the file system type fields in
    the returned list are valid.  Otherwise, they might not be.  */
 
 struct mount_entry *
-read_filesystem_list (int need_fs_type)
+read_file_system_list (int need_fs_type)
 {
   struct mount_entry *mount_list;
   struct mount_entry *me;
@@ -438,14 +438,14 @@ read_filesystem_list (int need_fs_type)
 #if defined MOUNTED_FS_STAT_DEV /* BeOS */
   {
     /* The next_dev() and fs_stat_dev() system calls give the list of
-       all filesystems, including the information returned by statvfs()
+       all file systems, including the information returned by statvfs()
        (fs type, total blocks, free blocks etc.), but without the mount
-       point. But on BeOS all filesystems except / are mounted in the
+       point. But on BeOS all file systems except / are mounted in the
        rootfs, directly under /.
        The directory name of the mount point is often, but not always,
        identical to the volume name of the device.
        We therefore get the list of subdirectories of /, and the list
-       of all filesystems, and match the two lists.  */
+       of all file systems, and match the two lists.  */
 
     DIR *dirp;
     struct rootdir_entry
@@ -744,12 +744,12 @@ read_filesystem_list (int need_fs_type)
     int n_entries;
     int i;
 
     /* Ask how many bytes to allocate for the mounted filesystem info.  */
     if (mntctl (MCTL_QUERY, sizeof bufsize, (struct vmount *) &bufsize) != 0)
       return NULL;
     entries = xmalloc (bufsize);
 
     /* Get the list of mounted filesystems.  */
     n_entries = mntctl (MCTL_QUERY, bufsize, (struct vmount *) entries);
     if (n_entries < 0)
       {
@@ -1,4 +1,4 @@
-/* mountlist.c -- return a list of mounted filesystems
+/* mountlist.c -- return a list of mounted file systems
    Copyright (C) 1991, 1992, 1997-2004 Free Software Foundation, Inc.
 
@@ -296,13 +296,13 @@ fstype_to_string (int t)
 #endif /* MOUNTED_VMOUNT */
 
-/* Return a list of the currently mounted filesystems, or NULL on error.
+/* Return a list of the currently mounted file systems, or NULL on error.
    Add each entry to the tail of the list so that they stay in order.
@@ -744,12 +744,12 @@ read_filesystem_list (int need_fs_type)
     int i;
 
-    /* Ask how many bytes to allocate for the mounted filesystem info.  */
+    /* Ask how many bytes to allocate for the mounted file system info.  */
     if (mntctl (MCTL_QUERY, sizeof bufsize, (struct vmount *) &bufsize) != 0)
       return NULL;
@@ -744,12 +744,12 @@ read_filesystem_list (int need_fs_type)
     entries = xmalloc (bufsize);
 
-    /* Get the list of mounted filesystems.  */
+    /* Get the list of mounted file systems.  */
     n_entries = mntctl (MCTL_QUERY, bufsize, (struct vmount *) entries);
     if (n_entries < 0)
Index: lib/mountlist.h
===================================================================
RCS file: /home/meyering/coreutils/cu/lib/mountlist.h,v
retrieving revision 1.14
diff -p -u -r1.14 mountlist.h
--- lib/mountlist.h     1 Nov 2003 08:54:35 -0000       1.14
+++ lib/mountlist.h     30 Jun 2004 14:14:22 -0000
@@ -1,6 +1,6 @@
 /* mountlist.h -- declarations for list of mounted filesystems
 
-   Copyright (C) 1991, 1992, 1998, 2000, 2001, 2002, 2003 Free
+   Copyright (C) 1991, 1992, 1998, 2000, 2001, 2002, 2003, 2004 Free
    Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -24,13 +24,13 @@ struct mount_entry
   char *me_mountdir;           /* Mount point directory pathname. */
   char *me_type;               /* "nfs", "4.2", etc. */
   dev_t me_dev;                        /* Device number of me_mountdir. */
-  unsigned int me_dummy : 1;   /* Nonzero for dummy filesystems. */
+  unsigned int me_dummy : 1;   /* Nonzero for dummy file systems. */
   unsigned int me_remote : 1;  /* Nonzero for remote fileystems. */
   unsigned int me_type_malloced : 1; /* Nonzero if me_type was malloced. */
   struct mount_entry *me_next;
 };
 
-struct mount_entry *read_filesystem_list (int need_fs_type);
+struct mount_entry *read_file_system_list (int need_fs_type);
 
 #ifndef ME_DUMMY
 # define ME_DUMMY(Fs_name, Fs_type) \
@@ -1,6 +1,6 @@
-/* mountlist.h -- declarations for list of mounted filesystems
+/* mountlist.h -- declarations for list of mounted file systems
 
Index: src/df.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/df.c,v
retrieving revision 1.159
diff -p -u -r1.159 df.c
--- src/df.c    6 May 2004 14:24:50 -0000       1.159
+++ src/df.c    30 Jun 2004 20:59:03 -0000
@@ -50,14 +50,14 @@ char *program_name;
 /* If nonzero, show inode information. */
 static int inode_format;
 
 /* If nonzero, show even filesystems with zero size or
    uninteresting types. */
 static int show_all_fs;
 
 /* If nonzero, show only local filesystems.  */
 static int show_local_fs;
 
 /* If nonzero, output data for each filesystem corresponding to a
    command line argument -- even if it's a dummy (automounter) entry.  */
 static int show_listed_fs;
 
@@ -79,7 +79,7 @@ static int require_sync = 0;
 /* Nonzero if errors have occurred. */
 static int exit_status;
 
 /* A filesystem type to display. */
 
 struct fs_type_list
 {
@@ -87,28 +87,28 @@ struct fs_type_list
   struct fs_type_list *fs_next;
 };
 
 /* Linked list of filesystem types to display.
    If `fs_select_list' is NULL, list all types.
    This table is generated dynamically from command-line options,
    rather than hardcoding into the program what it thinks are the
-   valid filesystem types; let the user specify any filesystem type
-   they want to, and if there are any filesystems of that type, they
+   valid file system types; let the user specify any file system type
+   they want to, and if there are any file systems of that type, they
    will be shown.
 
-   Some filesystem types:
+   Some file system types:
    4.2 4.3 ufs nfs swap ignore io vm efs dbg */
 
 static struct fs_type_list *fs_select_list;
 
 /* Linked list of filesystem types to omit.
    If the list is empty, don't exclude any types.  */
 
 static struct fs_type_list *fs_exclude_list;
 
 /* Linked list of mounted filesystems. */
 static struct mount_entry *mount_list;
 
 /* If nonzero, print filesystem type as well.  */
 static int print_type;
 
 /* For long options that have no equivalent short option, use a
@@ -198,7 +198,7 @@ print_header (void)
   printf (_(" Mounted on\n"));
 }
 
 /* If FSTYPE is a type of filesystem that should be listed,
    return nonzero, else zero. */
 
 static int
@@ -214,7 +214,7 @@ selected_fstype (const char *fstype)
   return 0;
 }
 
 /* If FSTYPE is a type of filesystem that should be omitted,
    return nonzero, else zero. */
 
 static int
@@ -255,8 +255,8 @@ df_readable (int negative, uintmax_t n, 
 
 /* Display a space listing for the disk device with absolute path DISK.
    If MOUNT_POINT is non-NULL, it is the path of the root of the
-   filesystem on DISK.
-   If FSTYPE is non-NULL, it is the type of the filesystem on DISK.
+   file system on DISK.
+   If FSTYPE is non-NULL, it is the type of the file system on DISK.
    If MOUNT_POINT is non-NULL, then DISK may be NULL -- certain systems may
    not be able to produce statistics in this case.
    ME_DUMMY and ME_REMOTE are the mount entry flags.  */
@@ -289,9 +289,9 @@ show_dev (const char *disk, const char *
   if (!selected_fstype (fstype) || excluded_fstype (fstype))
     return;
 
-  /* If MOUNT_POINT is NULL, then the filesystem is not mounted, and this
-     program reports on the filesystem that the special file is on.
-     It would be better to report on the unmounted filesystem,
+  /* If MOUNT_POINT is NULL, then the file system is not mounted, and this
+     program reports on the file system that the special file is on.
+     It would be better to report on the unmounted file system,
      but statfs doesn't do that on most systems.  */
   stat_file = mount_point ? mount_point : disk;
 
@@ -432,7 +432,7 @@ show_dev (const char *disk, const char *
   putchar ('\n');
 }
 
 /* Return the root mountpoint of the filesystem on which FILE exists, in
    malloced storage.  FILE_STAT should be the result of stating FILE.
    Give a diagnostic and return NULL if unable to determine the mount point.
    Exit if unable to restore current working directory.  */
@@ -481,7 +481,7 @@ find_mount_point (const char *file, cons
        }
     }
 
   /* Now walk up FILE's parents until we find another filesystem or /,
      chdiring as we go.  LAST_STAT holds stat information for the last place
      we visited.  */
   for (;;)
@@ -664,7 +664,7 @@ show_entry (const char *path, const stru
   show_point (path, statp);
 }
 
 /* Show all mounted filesystems, except perhaps those that are of
    an unselected type or are empty. */
 
 static void
@@ -677,7 +677,7 @@ show_all_entries (void)
              me->me_dummy, me->me_remote);
 }
 
 /* Add FSTYPE to the list of filesystem types to display. */
 
 static void
 add_fs_type (const char *fstype)
@@ -690,7 +690,7 @@ add_fs_type (const char *fstype)
   fs_select_list = fsp;
 }
 
 /* Add FSTYPE to the list of filesystem types to be omitted. */
 
 static void
 add_excluded_fs_type (const char *fstype)
@@ -713,15 +713,15 @@ usage (int status)
     {
       printf (_("Usage: %s [OPTION]... [FILE]...\n"), program_name);
       fputs (_("\
-Show information about the filesystem on which each FILE resides,\n\
-or all filesystems by default.\n\
+Show information about the file system on which each FILE resides,\n\
+or all file systems by default.\n\
 \n\
 "), stdout);
       fputs (_("\
 Mandatory arguments to long options are mandatory for short options too.\n\
 "), stdout);
       fputs (_("\
-  -a, --all             include filesystems having 0 blocks\n\
+  -a, --all             include file systems having 0 blocks\n\
   -B, --block-size=SIZE use SIZE-byte blocks\n\
   -h, --human-readable  print sizes in human readable format (e.g., 1K 234M 
2G)\n\
   -H, --si              likewise, but use powers of 1000 not 1024\n\
@@ -729,15 +729,15 @@ Mandatory arguments to long options are 
       fputs (_("\
   -i, --inodes          list inode information instead of block usage\n\
   -k                    like --block-size=1K\n\
-  -l, --local           limit listing to local filesystems\n\
+  -l, --local           limit listing to local file systems\n\
       --no-sync         do not invoke sync before getting usage info 
(default)\n\
 "), stdout);
       fputs (_("\
   -P, --portability     use the POSIX output format\n\
       --sync            invoke sync before getting usage info\n\
-  -t, --type=TYPE       limit listing to filesystems of type TYPE\n\
-  -T, --print-type      print filesystem type\n\
-  -x, --exclude-type=TYPE   limit listing to filesystems not of type TYPE\n\
+  -t, --type=TYPE       limit listing to file systems of type TYPE\n\
+  -T, --print-type      print file system type\n\
+  -x, --exclude-type=TYPE   limit listing to file systems not of type TYPE\n\
   -v                    (ignored)\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
@@ -876,7 +876,7 @@ main (int argc, char **argv)
       int i;
 
       /* stat all the given entries to make sure they get automounted,
-        if necessary, before reading the filesystem table.  */
+        if necessary, before reading the file system table.  */
       stats = xnmalloc (argc - optind, sizeof *stats);
       for (i = optind; i < argc; ++i)
        {
@@ -894,20 +894,20 @@ main (int argc, char **argv)
     }
 
   mount_list =
-    read_filesystem_list ((fs_select_list != NULL
-                          || fs_exclude_list != NULL
-                          || print_type
-                          || show_local_fs));
+    read_file_system_list ((fs_select_list != NULL
+                           || fs_exclude_list != NULL
+                           || print_type
+                           || show_local_fs));
 
   if (mount_list == NULL)
     {
       /* Couldn't read the table of mounted filesystems.
         Fail if df was invoked with no file name arguments;
         Otherwise, merely give a warning and proceed.  */
       const char *warning = (optind < argc ? _("Warning: ") : "");
       int status = (optind < argc ? 0 : EXIT_FAILURE);
       error (status, errno,
-            _("%scannot read table of mounted filesystems"), warning);
+            _("%scannot read table of mounted file systems"), warning);
     }
 
   if (require_sync)
@@ -917,7 +917,7 @@ main (int argc, char **argv)
     {
       int i;
 
       /* Display explicitly requested empty filesystems. */
       show_listed_fs = 1;
 
       if (n_valid_args > 0)
@@ -50,14 +50,14 @@ char *program_name;
 static int inode_format;
 
-/* If nonzero, show even filesystems with zero size or
+/* If nonzero, show even file systems with zero size or
    uninteresting types. */
 static int show_all_fs;
@@ -50,14 +50,14 @@ char *program_name;
 static int show_all_fs;
 
-/* If nonzero, show only local filesystems.  */
+/* If nonzero, show only local file systems.  */
 static int show_local_fs;
 
@@ -50,14 +50,14 @@ char *program_name;
 static int show_local_fs;
 
-/* If nonzero, output data for each filesystem corresponding to a
+/* If nonzero, output data for each file system corresponding to a
    command line argument -- even if it's a dummy (automounter) entry.  */
 static int show_listed_fs;
@@ -79,7 +79,7 @@ static int require_sync = 0;
 static int exit_status;
 
-/* A filesystem type to display. */
+/* A file system type to display. */
 
 struct fs_type_list
@@ -87,28 +87,28 @@ struct fs_type_list
 };
 
-/* Linked list of filesystem types to display.
+/* Linked list of file system types to display.
    If `fs_select_list' is NULL, list all types.
    This table is generated dynamically from command-line options,
@@ -87,28 +87,28 @@ struct fs_type_list
 static struct fs_type_list *fs_select_list;
 
-/* Linked list of filesystem types to omit.
+/* Linked list of file system types to omit.
    If the list is empty, don't exclude any types.  */
 
@@ -87,28 +87,28 @@ struct fs_type_list
 static struct fs_type_list *fs_exclude_list;
 
-/* Linked list of mounted filesystems. */
+/* Linked list of mounted file systems. */
 static struct mount_entry *mount_list;
 
@@ -87,28 +87,28 @@ struct fs_type_list
 static struct mount_entry *mount_list;
 
-/* If nonzero, print filesystem type as well.  */
+/* If nonzero, print file system type as well.  */
 static int print_type;
 
@@ -198,7 +198,7 @@ print_header (void)
 }
 
-/* If FSTYPE is a type of filesystem that should be listed,
+/* If FSTYPE is a type of file system that should be listed,
    return nonzero, else zero. */
 
@@ -214,7 +214,7 @@ selected_fstype (const char *fstype)
 }
 
-/* If FSTYPE is a type of filesystem that should be omitted,
+/* If FSTYPE is a type of file system that should be omitted,
    return nonzero, else zero. */
 
@@ -432,7 +432,7 @@ show_dev (const char *disk, const char *
 }
 
-/* Return the root mountpoint of the filesystem on which FILE exists, in
+/* Return the root mountpoint of the file system on which FILE exists, in
    malloced storage.  FILE_STAT should be the result of stating FILE.
    Give a diagnostic and return NULL if unable to determine the mount point.
@@ -481,7 +481,7 @@ find_mount_point (const char *file, cons
     }
 
-  /* Now walk up FILE's parents until we find another filesystem or /,
+  /* Now walk up FILE's parents until we find another file system or /,
      chdiring as we go.  LAST_STAT holds stat information for the last place
      we visited.  */
@@ -664,7 +664,7 @@ show_entry (const char *path, const stru
 }
 
-/* Show all mounted filesystems, except perhaps those that are of
+/* Show all mounted file systems, except perhaps those that are of
    an unselected type or are empty. */
 
@@ -677,7 +677,7 @@ show_all_entries (void)
 }
 
-/* Add FSTYPE to the list of filesystem types to display. */
+/* Add FSTYPE to the list of file system types to display. */
 
 static void
@@ -690,7 +690,7 @@ add_fs_type (const char *fstype)
 }
 
-/* Add FSTYPE to the list of filesystem types to be omitted. */
+/* Add FSTYPE to the list of file system types to be omitted. */
 
 static void
@@ -894,20 +894,20 @@ main (int argc, char **argv)
   if (mount_list == NULL)
     {
-      /* Couldn't read the table of mounted filesystems.
+      /* Couldn't read the table of mounted file systems.
         Fail if df was invoked with no file name arguments;
         Otherwise, merely give a warning and proceed.  */
@@ -917,7 +917,7 @@ main (int argc, char **argv)
       int i;
 
-      /* Display explicitly requested empty filesystems. */
+      /* Display explicitly requested empty file systems. */
       show_listed_fs = 1;
 
Index: src/shred.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/shred.c,v
retrieving revision 1.98
diff -p -u -r1.98 shred.c
--- src/shred.c 21 Jun 2004 15:03:35 -0000      1.98
+++ src/shred.c 30 Jun 2004 13:54:37 -0000
@@ -188,27 +188,27 @@ files, most people use the --remove opti
 "), stdout);
       fputs (_("\
 CAUTION: Note that shred relies on a very important assumption:\n\
-that the filesystem overwrites data in place.  This is the traditional\n\
-way to do things, but many modern filesystem designs do not satisfy this\n\
-assumption.  The following are examples of filesystems on which shred is\n\
+that the file system overwrites data in place.  This is the traditional\n\
+way to do things, but many modern file system designs do not satisfy this\n\
+assumption.  The following are examples of file systems on which shred is\n\
 not effective:\n\
 \n\
 "), stdout);
       fputs (_("\
 * log-structured or journaled filesystems, such as those supplied with\n\
   AIX and Solaris (and JFS, ReiserFS, XFS, Ext3, etc.)\n\
 \n\
-* filesystems that write redundant data and carry on even if some writes\n\
-  fail, such as RAID-based filesystems\n\
+* file systems that write redundant data and carry on even if some writes\n\
+  fail, such as RAID-based file systems\n\
 \n\
 * filesystems that make snapshots, such as Network Appliance's NFS server\n\
 \n\
 "), stdout);
       fputs (_("\
 * filesystems that cache in temporary locations, such as NFS\n\
   version 3 clients\n\
 \n\
-* compressed filesystems\n\
+* compressed file systems\n\
 \n\
 In addition, file system backups and remote mirrors may contain copies\n\
 of the file that cannot be removed, and that will allow a shredded file\n\
@@ -1446,7 +1446,7 @@ incname (char *name, size_t len)
  * invoke fdatasync and/or fsync on it.  This is non-standard, so don't
  * insist that it works: just fall back to a global sync in that case.
  * This is fairly significantly Unix-specific.  Of course, on any
  * filesystem with synchronous metadata updates, this is unnecessary.
  */
 static bool
 wipename (char *oldname, char const *qoldname, struct Options const *flags)
@@ -188,27 +188,27 @@ files, most people use the --remove opti
 "), stdout);
       fputs (_("\
-* log-structured or journaled filesystems, such as those supplied with\n\
+* log-structured or journaled file systems, such as those supplied with\n\
   AIX and Solaris (and JFS, ReiserFS, XFS, Ext3, etc.)\n\
 \n\
@@ -188,27 +188,27 @@ files, most people use the --remove opti
 \n\
-* filesystems that make snapshots, such as Network Appliance's NFS server\n\
+* file systems that make snapshots, such as Network Appliance's NFS server\n\
 \n\
 "), stdout);
@@ -188,27 +188,27 @@ files, most people use the --remove opti
 "), stdout);
       fputs (_("\
-* filesystems that cache in temporary locations, such as NFS\n\
+* file systems that cache in temporary locations, such as NFS\n\
   version 3 clients\n\
 \n\
@@ -1446,7 +1446,7 @@ incname (char *name, size_t len)
  * insist that it works: just fall back to a global sync in that case.
  * This is fairly significantly Unix-specific.  Of course, on any
- * filesystem with synchronous metadata updates, this is unnecessary.
+ * file system with synchronous metadata updates, this is unnecessary.
  */
 static bool
Index: src/stat.c
===================================================================
RCS file: /home/meyering/coreutils/cu/src/stat.c,v
retrieving revision 1.71
diff -p -u -r1.71 stat.c
--- src/stat.c  21 Jun 2004 15:03:35 -0000      1.71
+++ src/stat.c  30 Jun 2004 14:26:40 -0000
@@ -1,4 +1,4 @@
 /* stat.c -- display file or filesystem status
    Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation.
 
    This program is free software; you can redistribute it and/or modify
@@ -93,8 +93,9 @@
 static struct option const long_options[] = {
   {"link", no_argument, 0, 'l'}, /* deprecated.  FIXME: remove in 2003 */
   {"dereference", no_argument, 0, 'L'},
+  {"file-system", no_argument, 0, 'f'},
+  {"filesystem", no_argument, 0, 'f'}, /* obsolete and undocumented alias */
   {"format", required_argument, 0, 'c'},
-  {"filesystem", no_argument, 0, 'f'},
   {"terse", no_argument, 0, 't'},
   {GETOPT_HELP_OPTION_DECL},
   {GETOPT_VERSION_OPTION_DECL},
@@ -612,7 +613,7 @@ print_it (char const *masterformat, char
   free (dest);
 }
 
 /* stat the filesystem and print what we find */
 static void
 do_statfs (char const *filename, int terse, char const *format)
 {
@@ -699,9 +700,9 @@ usage (int status)
     {
       printf (_("Usage: %s [OPTION] FILE...\n"), program_name);
       fputs (_("\
-Display file or filesystem status.\n\
+Display file or file system status.\n\
 \n\
-  -f, --filesystem      display filesystem status instead of file status\n\
+  -f, --file-system     display file system status instead of file status\n\
   -c  --format=FORMAT   use the specified FORMAT instead of the default\n\
   -L, --dereference     follow links\n\
   -t, --terse           print the information in terse form\n\
@@ -710,7 +711,7 @@ Display file or filesystem status.\n\
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
 
       fputs (_("\n\
-The valid format sequences for files (without --filesystem):\n\
+The valid format sequences for files (without --file-system):\n\
 \n\
   %A   Access rights in human readable form\n\
   %a   Access rights in octal\n\
@@ -1,4 +1,4 @@
-/* stat.c -- display file or filesystem status
+/* stat.c -- display file or file system status
    Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation.
 
@@ -612,7 +613,7 @@ print_it (char const *masterformat, char
 }
 
-/* stat the filesystem and print what we find */
+/* Stat the file system and print what we find.  */
 static void
 do_statfs (char const *filename, int terse, char const *format)